@@ -4,9 +4,9 @@ __all__ = [
 
 __title__ = "covid-shared"
 __summary__ = "Shared utilities for the covid model pipeline."
-__uri__ = "https://stash.ihme.washington.edu/projects/CVD19/repos/covid-shared/browse"
+__uri__ = "https://github.com/ihmeuw/covid-shared"
 
-__version__ = '1.15.4'
+__version__ = '1.15.5'
 
 __author__ = "James Collins"
 __email__ = "collijk@uw.edu"
